@@ -60,7 +60,8 @@ def add_variant_qc_jobs(
             + f'--out-qc-ac-ht {qc_ac_ht_path} '
             + (f'--out-fam-stats-ht {fam_stats_ht_path} ' if ped_file else '')
             + (f'--fam-file {ped_file} ' if ped_file else '')
-            + f'--bucket {work_bucket} ',
+            + f'--bucket {work_bucket} '
+            + f'--n-partitions {scatter_count * 25}',
             max_age='8h',
             packages=utils.DATAPROC_PACKAGES,
             num_secondary_workers=scatter_count,
@@ -84,7 +85,7 @@ def add_variant_qc_jobs(
             max_age='8h',
             packages=utils.DATAPROC_PACKAGES,
             # Adding more workers as this is a much longer step
-            num_secondary_workers=scatter_count * 6,
+            num_secondary_workers=scatter_count,
             depends_on=[sample_qc_job],
             job_name='Var QC: generate frequencies',
         )
@@ -103,10 +104,11 @@ def add_variant_qc_jobs(
             f'--qc-ac-ht {qc_ac_ht_path} '
             f'--bucket {work_bucket} '
             f'--use-adj-genotypes '
-            f'--out-ht {rf_annotations_ht_path} ',
+            f'--out-ht {rf_annotations_ht_path} '
+            + f'--n-partitions {scatter_count * 25}',
             max_age='8h',
             packages=utils.DATAPROC_PACKAGES,
-            num_secondary_workers=scatter_count * 3,
+            num_secondary_workers=scatter_count,
             depends_on=[freq_job, var_qc_anno_job],
             job_name='Var QC: create RF annotations',
         )
@@ -166,6 +168,7 @@ def add_variant_qc_jobs(
                 vqsr_params_d=vqsr_params_d,
                 scatter_count=scatter_count,
                 output_vcf_path=vqsred_vcf_path,
+                overwrite=overwrite,
             )
         else:
             final_gathered_vcf_job = b.new_job('VQSR [reuse]')
